TestManager class

Constructors

TestManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smartlook ↔ Smartlook
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openNewSession() → Future<void>
openNewUser() → Future<void>
printSessionCallback(String message) → void
printUserCallback(String message) → void
registerUrlListener() → void
testEventProperties() → Future<void>
testEventTracking() → Future<void>
testPreferences() → Future<void>
testSensitivity() → void
testState() → Future<void>
testUser() → Future<void>
toString() → String
A string representation of this object.
inherited
unregisterListeners() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited