ElementData class

Constructors

ElementData({required String id, required String type, List<ElementData>? children, List<Skeleton>? skeletons, required Rect rect, double opacity = 1.0, bool isSensitive = false, bool doNotRecordWireframe = false, Matrix4? matrix, int? nativeViewId})

Properties

children ↔ List<ElementData>?
getter/setter pair
doNotRecordWireframe ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
isSensitive ↔ bool
getter/setter pair
matrix ↔ Matrix4?
getter/setter pair
nativeViewId ↔ int?
getter/setter pair
opacity ↔ double
getter/setter pair
rect ↔ Rect
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skeletons ↔ List<Skeleton>?
getter/setter pair
type ↔ String
getter/setter pair

Methods

addChildren(ElementData elementData) → void
applyAncestorMatrix(Matrix4? ancestorMatrix) → void
max(double a, double b) → double
min(double a, double b) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printElementData({int level = 0}) → void
printSkeletons() → void
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
transformRectAroundCenter(Matrix4 matrix, Rect rect) → Rect

Operators

operator ==(Object other) → bool
The equality operator.
inherited