Skeleton class

Constructors

Skeleton({required Rect? rect, required Color color, double opacity = 1.0, bool? isText})
Skeleton.withOffsetAndCrop(Skeleton skeleton, Rect? parentRect, Offset offset)

Properties

color ↔ Color
latefinal
hashCode → int
The hash code for this object.
no setterinherited
isText ↔ bool?
latefinal
opacity ↔ double
latefinal
rect ↔ Rect?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited