TextRect class
Constructors
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIcon → bool
-
final
- leftPosition → double
-
final
- lineAscent → double
-
final
- lineDescent → double
-
final
- lineLeft → double
-
final
- lineWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topPosition → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited