WidgetScraper class

Inheritance

Constructors

WidgetScraper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
rootElementData ↔ ElementData
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

describeRenderObject(ElementData activeElementData, Element element, bool isSensitive, void changeSensitivity()) → ElementDataNullable
getFirstElementDataFromElement(Element theElement, String type, {bool isSensitive = false}) → ElementData?
getRootElement(BuildContext buildContext) → Element?
getType<T>() → Type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrapeAllElements(ElementData activeElementData, Element element, bool isSensitive, Map<Type, bool> sensitiveWidgetsTypes) → void
scrapeRenderTree(BuildContext context, Map<Type, bool> sensitiveWidgetsTypes) → ElementData?
gets data from all visible objects inside a tree
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited