SmartlookHelperController class

Properties

containerKey → GlobalKey<State<StatefulWidget>>
final
descriptors ↔ Map<String, DefaultElementDescriptor>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
inputBorderPainterRuntimeName ↔ String?
getter/setter pair
isObfuscated ↔ bool
latefinal
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getWireframeTree(Map<Type, bool> sensitiveWidgetsTypes) → Future<ElementData?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → SmartlookHelperController
final
isTransitioningState ↔ bool
getter/setter pair

Static Methods

changeTransitioningState(bool isTransitioning) → void